import 'package:flutter/material.dart';
import 'package:getx_extended/export.dart';

import 'page/home_page.dart';

class App extends StatefulWidget {
  App() {
    Get.put(TaskController());
  }

  @override
  _AppState createState() => _AppState();
}

class _AppState extends State<App> with TickerProviderStateMixin {
  late AnimationController _animationController;

  @override
  void initState() {
    super.initState();
    _animationController = AnimationController(
      duration: Duration(milliseconds: 250),
      vsync: this,
    );
  }

  @override
  void dispose() {
    _animationController.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) => GetMaterialApp(
        home: QuickRoot(
          child: HomePage(),
          keyboardToolbar: _keyboardToolbar,
          loading: _loading(),
          consumeError: consumeError,
        ),
      );

  Future consumeError(dynamic error) async {
    await Get.showSnackbar(
        GetBar(message: "$error", duration: Duration(seconds: 2)));
  }

  Widget _loading() => Center(child: CircularProgressIndicator());

  Widget _keyboardToolbar(bool isKeyboardVisible) {
    if (isKeyboardVisible) {
      _animationController.forward();
    } else {
      _animationController.reverse();
    }
    return SlideTransition(
      position: Tween<Offset>(
        begin: Offset(0, 1),
        end: Offset(0, 0),
      ).animate(_animationController),
      child: isKeyboardVisible ? _toolbar() : Container(),
    );
  }

  Widget _toolbar() => Container(
        color: Colors.black,
        height: kToolbarHeight,
        child: Row(
          mainAxisAlignment: MainAxisAlignment.end,
          children: [
            TextButton(
              onPressed: () {
                FocusManager.instance.primaryFocus?.unfocus();
              },
              child: Text(
                "Done",
                style: TextStyle(color: Colors.white),
              ),
            )
          ],
        ),
      );
}
